# Change Log

## [0.6.0] - 2017-12-16
- [#5](https://github.com/mgrijalva/nose2-html-report/pull/5) add metadata to template context ([artragis](https://github.com/artragis))

## [0.5.0] - 2017-08-05
- Fix typo in documentation. `report_path` should have been `path`.

## [0.4.0] - 2017-05-11
- Fixed issue where tracebacks for error'ed tests were not captured

## [0.3.0] - 2017-02-03
- Updated packaging

## [0.2.0] - 2017-01-30
- Include Jinja2 template in distribution

## [0.1.0] - 2017-01-30
- Initial release

